#include "nsIDOM3Node.h"
#include "nsIDOMNSElement.h"
#include "nsIDOMEventTarget.h"
#include "nsIDOM3EventTarget.h"
#include "nsIDOMNSEventTarget.h"
#include "nsIWeakReference.h"
#include "nsIDOMDocument.h"
#include "nsIDOM3Document.h"
#include "nsIDOMNSDocument.h"
#include "nsIDOMDocumentEvent.h"
#include "nsIDOM3DocumentEvent.h"
#include "nsIDOMDocumentStyle.h"
#include "nsIDOMNSDocumentStyle.h"
#include "nsIDOMDocumentView.h"
#include "nsIDOMDocumentRange.h"
#include "nsIDOMDocumentTraversal.h"
#include "nsIDOMDocumentXBL.h"
#include "nsIDOMXPathEvaluator.h"
#include "nsGenericElement.h"
#include "nsDocument.h"
#include "nsIXPathEvaluatorInternal.h"
#include "nsDOMCID.h"
#include "nsComponentManagerUtils.h"

    enum nsDocument_QIActionType {
      nsDocument_OFFSET_THIS_ADDREF, nsDocument_LITERAL_CODE_nsIDOMXPathEvaluator, nsDocument_STATIC_POINTER, nsDocument_CC_ISUPPORTS
    };

    struct nsDocument_QIAction {
      const nsID *iid;
      nsDocument_QIActionType action;
      union {
        void *ptr;
        
        PRUint32 offset;
    
      } data;
    };

    NS_IMETHODIMP nsDocument::QueryInterface(REFNSIID aIID, void **aResult)
    {
      
        #ifdef DEBUG
        static const nsID kGQI_nsINode = { 0xd1c2e967, 0x854a, 0x436b, { 0xbf, 0xa5, 0xf6, 0xa4, 0x9a, 0x97, 0x46, 0x74 } };
        NS_ASSERTION(NS_GET_IID(nsINode).Equals(kGQI_nsINode),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMEventTarget = { 0x44a6597b, 0x9fc3, 0x4a8d, { 0xb7, 0xa4, 0xd9, 0x00, 0x9a, 0xbf, 0x9d, 0x15 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMEventTarget).Equals(kGQI_nsPIDOMEventTarget),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIScriptObjectPrincipal = { 0x3eedba38, 0x8d22, 0x41e1, { 0x81, 0x7a, 0x0e, 0x43, 0xe1, 0x65, 0xb6, 0x64 } };
        NS_ASSERTION(NS_GET_IID(nsIScriptObjectPrincipal).Equals(kGQI_nsIScriptObjectPrincipal),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIMutationObserver = { 0x32e68316, 0x67d4, 0x44a5, { 0x8d, 0x35, 0x0d, 0x39, 0x0f, 0xa9, 0xdf, 0x11 } };
        NS_ASSERTION(NS_GET_IID(nsIMutationObserver).Equals(kGQI_nsIMutationObserver),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIXPathEvaluatorInternal = { 0xb4b72daa, 0x65d6, 0x440f, { 0xb6, 0x08, 0xe2, 0xee, 0x9a, 0x82, 0xf3, 0x13 } };
        NS_ASSERTION(NS_GET_IID(nsIXPathEvaluatorInternal).Equals(kGQI_nsIXPathEvaluatorInternal),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionParticipant = { 0x9674489b, 0x1f6f, 0x4550, { 0xa7, 0x30, 0xcc, 0xae, 0xdd, 0x10, 0x4c, 0xf9 } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionParticipant).Equals(kGQI_nsCycleCollectionParticipant),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIDocument = { 0x626d86d2, 0x615f, 0x4a12, { 0x94, 0xd8, 0xe3, 0xdb, 0x3a, 0x29, 0x83, 0x72 } };
        NS_ASSERTION(NS_GET_IID(nsIDocument).Equals(kGQI_nsIDocument),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionISupports = { 0xc61eac14, 0x5f7a, 0x4481, { 0x96, 0x5e, 0x7e, 0xaa, 0x6e, 0xff, 0xa8, 0x5f } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionISupports).Equals(kGQI_nsCycleCollectionISupports),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIRadioGroupContainer = { 0x06de7839, 0xd0db, 0x47d3, { 0x82, 0x90, 0x3c, 0xb8, 0x62, 0x2e, 0xd9, 0x66 } };
        NS_ASSERTION(NS_GET_IID(nsIRadioGroupContainer).Equals(kGQI_nsIRadioGroupContainer),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        

      static const PRUint8 kLookupTable[] = {
#ifdef IS_BIG_ENDIAN
        10,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
20,
0xFF,
0xFF,
0xFF,
21,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
15,
0xFF,
0xFF,
0xFF,
25,
0xFF,
5,
0xFF,
8,
14,
0xFF,
16,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
26,
0xFF,
0xFF,
11,
22,
0xFF,
0xFF,
0xFF,
0xFF,
19,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
3,
27,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
24,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
6,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
0xFF,
4,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
9,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
23,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0,
0xFF,
0xFF,
0xFF
#else
        10,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
20,
0xFF,
0xFF,
0xFF,
21,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
15,
0xFF,
0xFF,
0xFF,
25,
0xFF,
5,
0xFF,
8,
14,
0xFF,
16,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
26,
0xFF,
0xFF,
11,
22,
0xFF,
0xFF,
0xFF,
0xFF,
19,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
3,
27,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
24,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
6,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
0xFF,
4,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
9,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
23,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0,
0xFF,
0xFF,
0xFF
#endif
      };

      static const nsDocument_QIAction kActionTable[] = {
        
        {
          &(NS_GET_IID(nsIDOMNode)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNode*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsINode)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsINode*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsPIDOMEventTarget)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMEventTarget*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIScriptObjectPrincipal)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIScriptObjectPrincipal*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSEventTarget)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSEventTarget*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIMutationObserver)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIMutationObserver*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentRange)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentRange*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentStyle)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentStyle*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOM3Node)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOM3Node*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentEvent)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentEvent*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsISupports)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupports*>(
           static_cast<nsIDocument*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIXPathEvaluatorInternal)),
          nsDocument_LITERAL_CODE_nsIDOMXPathEvaluator,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSDocument)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSDocument*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOM3Document)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOM3Document*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOM3DocumentEvent)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOM3DocumentEvent*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSDocumentStyle)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSDocumentStyle*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionParticipant)),
          nsDocument_STATIC_POINTER,
          { &NS_CYCLE_COLLECTION_NAME(nsDocument) }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentView)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentView*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDocument)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDocument*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMEventTarget)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMEventTarget*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsISupportsWeakReference)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupportsWeakReference*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMXPathEvaluator)),
          nsDocument_LITERAL_CODE_nsIDOMXPathEvaluator,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentXBL)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentXBL*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocument)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocument*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentTraversal)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentTraversal*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionISupports)),
          nsDocument_CC_ISUPPORTS,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOM3EventTarget)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOM3EventTarget*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIRadioGroupContainer)),
          nsDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIRadioGroupContainer*>(static_cast<nsDocument*>(((nsDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(((nsDocument*) 0x1000))))
   }
        },
    
      };

      nsISupports* found = nsnull;
      const nsDocument_QIAction *entry;
      PRUint32 index =
#ifdef IS_BIG_ENDIAN
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#else
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#endif

      PRUint8 action = kLookupTable[index];
      if (action == 0xFF)
        goto unfound;

      entry = kActionTable + action;
      if (!entry->iid->Equals(aIID))
        goto unfound;

      
      switch (entry->action) {
      
      case nsDocument_OFFSET_THIS_ADDREF:
        
        found = reinterpret_cast<nsISupports*>(reinterpret_cast<char*>(this) + entry->data.offset);
        goto exit_addref;
    
    
      case nsDocument_LITERAL_CODE_nsIDOMXPathEvaluator:
        if (!mXPathEvaluatorTearoff) {nsresult rv;mXPathEvaluatorTearoff =do_CreateInstance(NS_XPATH_EVALUATOR_CONTRACTID,static_cast<nsIDocument *>(this), &rv);NS_ENSURE_SUCCESS(rv, rv);}return mXPathEvaluatorTearoff->QueryInterface(aIID, aResult);
    
      case nsDocument_STATIC_POINTER:
        *aResult = entry->data.ptr;
                   return NS_OK;
    
      case nsDocument_CC_ISUPPORTS:
        
        found = NS_CYCLE_COLLECTION_CLASSNAME(nsDocument)::Upcast(this);
        goto exit_nullcheck_addref;
    
    
      }
    

      NS_NOTREACHED("Unhandled case?");

      
    exit_nullcheck_addref:
      if (!found)
        return NS_ERROR_OUT_OF_MEMORY;
    

    exit_addref:
      NS_ASSERTION(found, "Interface should have been found by now.");
      found->AddRef();
      *aResult = found;
      return NS_OK;

    unfound:
      
      *aResult = nsnull;
      return NS_NOINTERFACE;
    
    }

    enum nsGenericElement_QIActionType {
      nsGenericElement_OFFSET_THIS_ADDREF, nsGenericElement_NS_TEAROFF_nsIDOMNSElement, nsGenericElement_CC_ISUPPORTS, nsGenericElement_NS_TEAROFF_nsIDOM3EventTarget, nsGenericElement_NS_TEAROFF_nsIDOMEventTarget, nsGenericElement_NS_TEAROFF_nsIDOM3Node, nsGenericElement_NS_TEAROFF_nsISupportsWeakReference, nsGenericElement_STATIC_POINTER, nsGenericElement_NS_TEAROFF_nsIDOMNSEventTarget
    };

    struct nsGenericElement_QIAction {
      const nsID *iid;
      nsGenericElement_QIActionType action;
      union {
        void *ptr;
        
        PRUint32 offset;
    
      } data;
    };

    NS_IMETHODIMP nsGenericElement::QueryInterface(REFNSIID aIID, void **aResult)
    {
      
        #ifdef DEBUG
        static const nsID kGQI_nsINode = { 0xd1c2e967, 0x854a, 0x436b, { 0xbf, 0xa5, 0xf6, 0xa4, 0x9a, 0x97, 0x46, 0x74 } };
        NS_ASSERTION(NS_GET_IID(nsINode).Equals(kGQI_nsINode),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMEventTarget = { 0x44a6597b, 0x9fc3, 0x4a8d, { 0xb7, 0xa4, 0xd9, 0x00, 0x9a, 0xbf, 0x9d, 0x15 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMEventTarget).Equals(kGQI_nsPIDOMEventTarget),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIContent = { 0xfba9aa39, 0x016e, 0x4d5d, { 0xab, 0x62, 0x22, 0xa1, 0xb8, 0x4a, 0x3c, 0x7b } };
        NS_ASSERTION(NS_GET_IID(nsIContent).Equals(kGQI_nsIContent),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionParticipant = { 0x9674489b, 0x1f6f, 0x4550, { 0xa7, 0x30, 0xcc, 0xae, 0xdd, 0x10, 0x4c, 0xf9 } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionParticipant).Equals(kGQI_nsCycleCollectionParticipant),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionISupports = { 0xc61eac14, 0x5f7a, 0x4481, { 0x96, 0x5e, 0x7e, 0xaa, 0x6e, 0xff, 0xa8, 0x5f } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionISupports).Equals(kGQI_nsCycleCollectionISupports),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        

      static const PRUint8 kLookupTable[] = {
#ifdef IS_BIG_ENDIAN
        5,
0,
11,
3,
4,
10,
0xFF,
1,
7,
8,
9,
0xFF,
0xFF,
0xFF,
6,
2
#else
        5,
0,
11,
3,
4,
10,
0xFF,
1,
7,
8,
9,
0xFF,
0xFF,
0xFF,
6,
2
#endif
      };

      static const nsGenericElement_QIAction kActionTable[] = {
        
        {
          &(NS_GET_IID(nsINode)),
          nsGenericElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsINode*>(static_cast<nsGenericElement*>(((nsGenericElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(((nsGenericElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsPIDOMEventTarget)),
          nsGenericElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMEventTarget*>(static_cast<nsGenericElement*>(((nsGenericElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(((nsGenericElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIContent)),
          nsGenericElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIContent*>(static_cast<nsGenericElement*>(((nsGenericElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(((nsGenericElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionParticipant)),
          nsGenericElement_STATIC_POINTER,
          { &NS_CYCLE_COLLECTION_NAME(nsGenericElement) }
        },
    
        {
          &(NS_GET_IID(nsIDOM3Node)),
          nsGenericElement_NS_TEAROFF_nsIDOM3Node,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupports)),
          nsGenericElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupports*>(
           static_cast<nsIContent*>(static_cast<nsGenericElement*>(((nsGenericElement*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(((nsGenericElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSElement)),
          nsGenericElement_NS_TEAROFF_nsIDOMNSElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMEventTarget)),
          nsGenericElement_NS_TEAROFF_nsIDOMEventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSEventTarget)),
          nsGenericElement_NS_TEAROFF_nsIDOMNSEventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionISupports)),
          nsGenericElement_CC_ISUPPORTS,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOM3EventTarget)),
          nsGenericElement_NS_TEAROFF_nsIDOM3EventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupportsWeakReference)),
          nsGenericElement_NS_TEAROFF_nsISupportsWeakReference,
          {0}
        },
    
      };

      nsISupports* found = nsnull;
      const nsGenericElement_QIAction *entry;
      PRUint32 index =
#ifdef IS_BIG_ENDIAN
        (reinterpret_cast<const PRUint32*>(&aIID)[3] & 0x3c00) >> 10;
#else
        (reinterpret_cast<const PRUint32*>(&aIID)[3] & 0x3c0000) >> 18;
#endif

      PRUint8 action = kLookupTable[index];
      if (action == 0xFF)
        goto unfound;

      entry = kActionTable + action;
      if (!entry->iid->Equals(aIID))
        goto unfound;

      
      switch (entry->action) {
      
      case nsGenericElement_OFFSET_THIS_ADDREF:
        
        found = reinterpret_cast<nsISupports*>(reinterpret_cast<char*>(this) + entry->data.offset);
        goto exit_addref;
    
    
      case nsGenericElement_NS_TEAROFF_nsIDOMNSElement:
        
            found = static_cast<nsIDOMNSElement*>(new nsNSElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsGenericElement_CC_ISUPPORTS:
        
        found = NS_CYCLE_COLLECTION_CLASSNAME(nsGenericElement)::Upcast(this);
        goto exit_nullcheck_addref;
    
    
      case nsGenericElement_NS_TEAROFF_nsIDOM3EventTarget:
        
            found = static_cast<nsIDOM3EventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsGenericElement_NS_TEAROFF_nsIDOMEventTarget:
        
            found = static_cast<nsIDOMEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsGenericElement_NS_TEAROFF_nsIDOM3Node:
        
            found = static_cast<nsIDOM3Node*>(new nsNode3Tearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsGenericElement_NS_TEAROFF_nsISupportsWeakReference:
        
            found = static_cast<nsISupportsWeakReference*>(new nsNodeSupportsWeakRefTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsGenericElement_STATIC_POINTER:
        *aResult = entry->data.ptr;
                   return NS_OK;
    
      case nsGenericElement_NS_TEAROFF_nsIDOMNSEventTarget:
        
            found = static_cast<nsIDOMNSEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      }
    

      NS_NOTREACHED("Unhandled case?");

      
    exit_nullcheck_addref:
      if (!found)
        return NS_ERROR_OUT_OF_MEMORY;
    

    exit_addref:
      NS_ASSERTION(found, "Interface should have been found by now.");
      found->AddRef();
      *aResult = found;
      return NS_OK;

    unfound:
      
      *aResult = nsnull;
      return NS_NOINTERFACE;
    
    }
