#include "nsIDOM3Node.h"
#include "nsIDOMNSElement.h"
#include "nsIDOMEventTarget.h"
#include "nsIDOM3EventTarget.h"
#include "nsIDOMNSEventTarget.h"
#include "nsIWeakReference.h"
#include "nsIDOMDocument.h"
#include "nsIDOM3Document.h"
#include "nsIDOMNSDocument.h"
#include "nsIDOMDocumentEvent.h"
#include "nsIDOM3DocumentEvent.h"
#include "nsIDOMDocumentStyle.h"
#include "nsIDOMNSDocumentStyle.h"
#include "nsIDOMDocumentView.h"
#include "nsIDOMDocumentRange.h"
#include "nsIDOMDocumentTraversal.h"
#include "nsIDOMDocumentXBL.h"
#include "nsIDOMXPathEvaluator.h"
#include "nsGenericElement.h"
#include "nsDocument.h"
#include "nsIXPathEvaluatorInternal.h"
#include "nsDOMCID.h"
#include "nsComponentManagerUtils.h"
#include "nsIDOMNSHTMLElement.h"
#include "nsIDOMElementCSSInlineStyle.h"
#include "nsIDOMHTMLElement.h"
#include "nsIDOMNSHTMLFrameElement.h"
#include "nsIFrameLoader.h"
#include "nsGenericHTMLElement.h"
#include "nsIDOMHTMLAnchorElement.h"
#include "nsIDOMNSHTMLAnchorElement2.h"
#include "nsIDOMHTMLDivElement.h"
#include "nsIDOMHTMLFrameElement.h"
#include "nsIDOMHTMLFrameSetElement.h"
#include "nsIDOMHTMLIFrameElement.h"
#include "nsHTMLAnchorElement.h"
#include "nsHTMLDivElement.h"
#include "nsHTMLSpanElement.h"
#include "nsHTMLFrameElement.h"
#include "nsHTMLFrameSetElement.h"
#include "nsHTMLIFrameElement.h"

    enum nsHTMLFrameSetElement_QIActionType {
      nsHTMLFrameSetElement_OFFSET_THIS_ADDREF, nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMNSElement, nsHTMLFrameSetElement_NS_TEAROFF_nsISupportsWeakReference, nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMNSHTMLElement, nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle, nsHTMLFrameSetElement_CC_ISUPPORTS, nsHTMLFrameSetElement_DOMCI, nsHTMLFrameSetElement_STATIC_POINTER, nsHTMLFrameSetElement_NS_TEAROFF_nsIDOM3Node, nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMNSEventTarget, nsHTMLFrameSetElement_NS_TEAROFF_nsIDOM3EventTarget, nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMEventTarget
    };

    struct nsHTMLFrameSetElement_QIAction {
      const nsID *iid;
      nsHTMLFrameSetElement_QIActionType action;
      union {
        void *ptr;
        
        PRUint32 offset;
    
      } data;
    };

    NS_IMETHODIMP nsHTMLFrameSetElement::QueryInterface(REFNSIID aIID, void **aResult)
    {
      
        #ifdef DEBUG
        static const nsID kGQI_nsINode = { 0xd1c2e967, 0x854a, 0x436b, { 0xbf, 0xa5, 0xf6, 0xa4, 0x9a, 0x97, 0x46, 0x74 } };
        NS_ASSERTION(NS_GET_IID(nsINode).Equals(kGQI_nsINode),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMEventTarget = { 0x44a6597b, 0x9fc3, 0x4a8d, { 0xb7, 0xa4, 0xd9, 0x00, 0x9a, 0xbf, 0x9d, 0x15 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMEventTarget).Equals(kGQI_nsPIDOMEventTarget),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIFrameSetElement = { 0xeefe0fe5, 0x44ac, 0x4d7f, { 0xa7, 0x51, 0xf4, 0xaa, 0x5f, 0x22, 0xb0, 0xbf } };
        NS_ASSERTION(NS_GET_IID(nsIFrameSetElement).Equals(kGQI_nsIFrameSetElement),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionParticipant = { 0x9674489b, 0x1f6f, 0x4550, { 0xa7, 0x30, 0xcc, 0xae, 0xdd, 0x10, 0x4c, 0xf9 } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionParticipant).Equals(kGQI_nsCycleCollectionParticipant),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIContent = { 0xfba9aa39, 0x016e, 0x4d5d, { 0xab, 0x62, 0x22, 0xa1, 0xb8, 0x4a, 0x3c, 0x7b } };
        NS_ASSERTION(NS_GET_IID(nsIContent).Equals(kGQI_nsIContent),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionISupports = { 0xc61eac14, 0x5f7a, 0x4481, { 0x96, 0x5e, 0x7e, 0xaa, 0x6e, 0xff, 0xa8, 0x5f } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionISupports).Equals(kGQI_nsCycleCollectionISupports),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIClassInfo = { 0x986c11d0, 0xf340, 0x11d4, { 0x90, 0x75, 0x00, 0x10, 0xa4, 0xe7, 0x3d, 0x9a } };
        NS_ASSERTION(NS_GET_IID(nsIClassInfo).Equals(kGQI_nsIClassInfo),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        

      static const PRUint8 kLookupTable[] = {
#ifdef IS_BIG_ENDIAN
        9,
0xFF,
0xFF,
0xFF,
0xFF,
15,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
16,
0xFF,
0xFF,
0xFF,
6,
10,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
13,
11,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
0xFF,
0xFF,
0xFF,
19,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
4,
0xFF,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
0xFF,
3,
0,
0xFF,
0xFF,
0xFF
#else
        9,
0xFF,
0xFF,
0xFF,
0xFF,
15,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
16,
0xFF,
0xFF,
0xFF,
6,
10,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
13,
11,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
0xFF,
0xFF,
0xFF,
19,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
4,
0xFF,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
0xFF,
3,
0,
0xFF,
0xFF,
0xFF
#endif
      };

      static const nsHTMLFrameSetElement_QIAction kActionTable[] = {
        
        {
          &(NS_GET_IID(nsIDOMNode)),
          nsHTMLFrameSetElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNode*>(((nsHTMLFrameSetElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLFrameSetElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsINode)),
          nsHTMLFrameSetElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsINode*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMElement)),
          nsHTMLFrameSetElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMElement*>(((nsHTMLFrameSetElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLFrameSetElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsPIDOMEventTarget)),
          nsHTMLFrameSetElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMEventTarget*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIFrameSetElement)),
          nsHTMLFrameSetElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIFrameSetElement*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionParticipant)),
          nsHTMLFrameSetElement_STATIC_POINTER,
          { &NS_CYCLE_COLLECTION_NAME(nsHTMLFrameSetElement) }
        },
    
        {
          &(NS_GET_IID(nsIDOM3Node)),
          nsHTMLFrameSetElement_NS_TEAROFF_nsIDOM3Node,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLElement)),
          nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMNSHTMLElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMElementCSSInlineStyle)),
          nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupports)),
          nsHTMLFrameSetElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupports*>(
           static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSElement)),
          nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMNSElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIContent)),
          nsHTMLFrameSetElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMEventTarget)),
          nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMEventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLFrameSetElement)),
          nsHTMLFrameSetElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLFrameSetElement*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLFrameSetElement*>(((nsHTMLFrameSetElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsISupportsWeakReference)),
          nsHTMLFrameSetElement_NS_TEAROFF_nsISupportsWeakReference,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLElement)),
          nsHTMLFrameSetElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLElement*>(((nsHTMLFrameSetElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLFrameSetElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionISupports)),
          nsHTMLFrameSetElement_CC_ISUPPORTS,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOM3EventTarget)),
          nsHTMLFrameSetElement_NS_TEAROFF_nsIDOM3EventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIClassInfo)),
          nsHTMLFrameSetElement_DOMCI,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSEventTarget)),
          nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMNSEventTarget,
          {0}
        },
    
      };

      nsISupports* found = nsnull;
      const nsHTMLFrameSetElement_QIAction *entry;
      PRUint32 index =
#ifdef IS_BIG_ENDIAN
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#else
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#endif

      PRUint8 action = kLookupTable[index];
      if (action == 0xFF)
        goto unfound;

      entry = kActionTable + action;
      if (!entry->iid->Equals(aIID))
        goto unfound;

      
      switch (entry->action) {
      
      case nsHTMLFrameSetElement_OFFSET_THIS_ADDREF:
        
        found = reinterpret_cast<nsISupports*>(reinterpret_cast<char*>(this) + entry->data.offset);
        goto exit_addref;
    
    
      case nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMNSElement:
        
            found = static_cast<nsIDOMNSElement*>(new nsNSElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameSetElement_NS_TEAROFF_nsISupportsWeakReference:
        
            found = static_cast<nsISupportsWeakReference*>(new nsNodeSupportsWeakRefTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMNSHTMLElement:
        
            found = static_cast<nsIDOMNSHTMLElement*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle:
        
            found = static_cast<nsIDOMElementCSSInlineStyle*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameSetElement_CC_ISUPPORTS:
        
        found = NS_CYCLE_COLLECTION_CLASSNAME(nsHTMLFrameSetElement)::Upcast(this);
        goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameSetElement_DOMCI:
        
      found = NS_GetDOMClassInfoInstance(eDOMClassInfo_HTMLFrameSetElement_id);
      goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameSetElement_STATIC_POINTER:
        *aResult = entry->data.ptr;
                   return NS_OK;
    
      case nsHTMLFrameSetElement_NS_TEAROFF_nsIDOM3Node:
        
            found = static_cast<nsIDOM3Node*>(new nsNode3Tearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMNSEventTarget:
        
            found = static_cast<nsIDOMNSEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameSetElement_NS_TEAROFF_nsIDOM3EventTarget:
        
            found = static_cast<nsIDOM3EventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameSetElement_NS_TEAROFF_nsIDOMEventTarget:
        
            found = static_cast<nsIDOMEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      }
    

      NS_NOTREACHED("Unhandled case?");

      
    exit_nullcheck_addref:
      if (!found)
        return NS_ERROR_OUT_OF_MEMORY;
    

    exit_addref:
      NS_ASSERTION(found, "Interface should have been found by now.");
      found->AddRef();
      *aResult = found;
      return NS_OK;

    unfound:
      return PostQueryInterface(aIID, aResult);
    }

    enum nsHTMLDivElement_QIActionType {
      nsHTMLDivElement_OFFSET_THIS_ADDREF, nsHTMLDivElement_NS_TEAROFF_nsIDOMNSElement, nsHTMLDivElement_NS_TEAROFF_nsISupportsWeakReference, nsHTMLDivElement_NS_TEAROFF_nsIDOMNSHTMLElement, nsHTMLDivElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle, nsHTMLDivElement_CC_ISUPPORTS, nsHTMLDivElement_DOMCI, nsHTMLDivElement_STATIC_POINTER, nsHTMLDivElement_NS_TEAROFF_nsIDOM3Node, nsHTMLDivElement_NS_TEAROFF_nsIDOMNSEventTarget, nsHTMLDivElement_NS_TEAROFF_nsIDOM3EventTarget, nsHTMLDivElement_NS_TEAROFF_nsIDOMEventTarget
    };

    struct nsHTMLDivElement_QIAction {
      const nsID *iid;
      nsHTMLDivElement_QIActionType action;
      union {
        void *ptr;
        
        PRUint32 offset;
    
      } data;
    };

    NS_IMETHODIMP nsHTMLDivElement::QueryInterface(REFNSIID aIID, void **aResult)
    {
      
        #ifdef DEBUG
        static const nsID kGQI_nsINode = { 0xd1c2e967, 0x854a, 0x436b, { 0xbf, 0xa5, 0xf6, 0xa4, 0x9a, 0x97, 0x46, 0x74 } };
        NS_ASSERTION(NS_GET_IID(nsINode).Equals(kGQI_nsINode),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMEventTarget = { 0x44a6597b, 0x9fc3, 0x4a8d, { 0xb7, 0xa4, 0xd9, 0x00, 0x9a, 0xbf, 0x9d, 0x15 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMEventTarget).Equals(kGQI_nsPIDOMEventTarget),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIContent = { 0xfba9aa39, 0x016e, 0x4d5d, { 0xab, 0x62, 0x22, 0xa1, 0xb8, 0x4a, 0x3c, 0x7b } };
        NS_ASSERTION(NS_GET_IID(nsIContent).Equals(kGQI_nsIContent),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionParticipant = { 0x9674489b, 0x1f6f, 0x4550, { 0xa7, 0x30, 0xcc, 0xae, 0xdd, 0x10, 0x4c, 0xf9 } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionParticipant).Equals(kGQI_nsCycleCollectionParticipant),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionISupports = { 0xc61eac14, 0x5f7a, 0x4481, { 0x96, 0x5e, 0x7e, 0xaa, 0x6e, 0xff, 0xa8, 0x5f } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionISupports).Equals(kGQI_nsCycleCollectionISupports),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIClassInfo = { 0x986c11d0, 0xf340, 0x11d4, { 0x90, 0x75, 0x00, 0x10, 0xa4, 0xe7, 0x3d, 0x9a } };
        NS_ASSERTION(NS_GET_IID(nsIClassInfo).Equals(kGQI_nsIClassInfo),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        

      static const PRUint8 kLookupTable[] = {
#ifdef IS_BIG_ENDIAN
        10,
0xFF,
0xFF,
0xFF,
0xFF,
15,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
16,
0xFF,
0xFF,
0xFF,
7,
11,
0xFF,
6,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
9,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
18,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
3,
0xFF,
0xFF,
4,
0,
0xFF,
0xFF,
0xFF
#else
        10,
0xFF,
0xFF,
0xFF,
0xFF,
15,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
16,
0xFF,
0xFF,
0xFF,
7,
11,
0xFF,
6,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
9,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
18,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
3,
0xFF,
0xFF,
4,
0,
0xFF,
0xFF,
0xFF
#endif
      };

      static const nsHTMLDivElement_QIAction kActionTable[] = {
        
        {
          &(NS_GET_IID(nsIDOMNode)),
          nsHTMLDivElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNode*>(((nsHTMLDivElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLDivElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsINode)),
          nsHTMLDivElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsINode*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLDivElement*>(((nsHTMLDivElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLDivElement*>(((nsHTMLDivElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLDivElement)),
          nsHTMLDivElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLDivElement*>(static_cast<nsHTMLDivElement*>(((nsHTMLDivElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLDivElement*>(((nsHTMLDivElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMElement)),
          nsHTMLDivElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMElement*>(((nsHTMLDivElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLDivElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsPIDOMEventTarget)),
          nsHTMLDivElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMEventTarget*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLDivElement*>(((nsHTMLDivElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLDivElement*>(((nsHTMLDivElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIContent)),
          nsHTMLDivElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLDivElement*>(((nsHTMLDivElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLDivElement*>(((nsHTMLDivElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionParticipant)),
          nsHTMLDivElement_STATIC_POINTER,
          { &NS_CYCLE_COLLECTION_NAME(nsHTMLDivElement) }
        },
    
        {
          &(NS_GET_IID(nsIDOM3Node)),
          nsHTMLDivElement_NS_TEAROFF_nsIDOM3Node,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLElement)),
          nsHTMLDivElement_NS_TEAROFF_nsIDOMNSHTMLElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMElementCSSInlineStyle)),
          nsHTMLDivElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupports)),
          nsHTMLDivElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupports*>(
           static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLDivElement*>(((nsHTMLDivElement*) 0x1000))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLDivElement*>(((nsHTMLDivElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSElement)),
          nsHTMLDivElement_NS_TEAROFF_nsIDOMNSElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMEventTarget)),
          nsHTMLDivElement_NS_TEAROFF_nsIDOMEventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOM3EventTarget)),
          nsHTMLDivElement_NS_TEAROFF_nsIDOM3EventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupportsWeakReference)),
          nsHTMLDivElement_NS_TEAROFF_nsISupportsWeakReference,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLElement)),
          nsHTMLDivElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLElement*>(((nsHTMLDivElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLDivElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionISupports)),
          nsHTMLDivElement_CC_ISUPPORTS,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIClassInfo)),
          nsHTMLDivElement_DOMCI,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSEventTarget)),
          nsHTMLDivElement_NS_TEAROFF_nsIDOMNSEventTarget,
          {0}
        },
    
      };

      nsISupports* found = nsnull;
      const nsHTMLDivElement_QIAction *entry;
      PRUint32 index =
#ifdef IS_BIG_ENDIAN
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#else
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#endif

      PRUint8 action = kLookupTable[index];
      if (action == 0xFF)
        goto unfound;

      entry = kActionTable + action;
      if (!entry->iid->Equals(aIID))
        goto unfound;

      
      switch (entry->action) {
      
      case nsHTMLDivElement_OFFSET_THIS_ADDREF:
        
        found = reinterpret_cast<nsISupports*>(reinterpret_cast<char*>(this) + entry->data.offset);
        goto exit_addref;
    
    
      case nsHTMLDivElement_NS_TEAROFF_nsIDOMNSElement:
        
            found = static_cast<nsIDOMNSElement*>(new nsNSElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLDivElement_NS_TEAROFF_nsISupportsWeakReference:
        
            found = static_cast<nsISupportsWeakReference*>(new nsNodeSupportsWeakRefTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLDivElement_NS_TEAROFF_nsIDOMNSHTMLElement:
        
            found = static_cast<nsIDOMNSHTMLElement*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLDivElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle:
        
            found = static_cast<nsIDOMElementCSSInlineStyle*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLDivElement_CC_ISUPPORTS:
        
        found = NS_CYCLE_COLLECTION_CLASSNAME(nsHTMLDivElement)::Upcast(this);
        goto exit_nullcheck_addref;
    
    
      case nsHTMLDivElement_DOMCI:
        
      found = NS_GetDOMClassInfoInstance(eDOMClassInfo_HTMLDivElement_id);
      goto exit_nullcheck_addref;
    
    
      case nsHTMLDivElement_STATIC_POINTER:
        *aResult = entry->data.ptr;
                   return NS_OK;
    
      case nsHTMLDivElement_NS_TEAROFF_nsIDOM3Node:
        
            found = static_cast<nsIDOM3Node*>(new nsNode3Tearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLDivElement_NS_TEAROFF_nsIDOMNSEventTarget:
        
            found = static_cast<nsIDOMNSEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLDivElement_NS_TEAROFF_nsIDOM3EventTarget:
        
            found = static_cast<nsIDOM3EventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLDivElement_NS_TEAROFF_nsIDOMEventTarget:
        
            found = static_cast<nsIDOMEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      }
    

      NS_NOTREACHED("Unhandled case?");

      
    exit_nullcheck_addref:
      if (!found)
        return NS_ERROR_OUT_OF_MEMORY;
    

    exit_addref:
      NS_ASSERTION(found, "Interface should have been found by now.");
      found->AddRef();
      *aResult = found;
      return NS_OK;

    unfound:
      return PostQueryInterface(aIID, aResult);
    }

    enum nsHTMLFrameElement_QIActionType {
      nsHTMLFrameElement_OFFSET_THIS_ADDREF, nsHTMLFrameElement_NS_TEAROFF_nsIDOMNSElement, nsHTMLFrameElement_NS_TEAROFF_nsISupportsWeakReference, nsHTMLFrameElement_NS_TEAROFF_nsIDOMNSHTMLElement, nsHTMLFrameElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle, nsHTMLFrameElement_CC_ISUPPORTS, nsHTMLFrameElement_DOMCI, nsHTMLFrameElement_STATIC_POINTER, nsHTMLFrameElement_NS_TEAROFF_nsIDOM3Node, nsHTMLFrameElement_NS_TEAROFF_nsIDOMNSEventTarget, nsHTMLFrameElement_NS_TEAROFF_nsIDOM3EventTarget, nsHTMLFrameElement_NS_TEAROFF_nsIDOMEventTarget
    };

    struct nsHTMLFrameElement_QIAction {
      const nsID *iid;
      nsHTMLFrameElement_QIActionType action;
      union {
        void *ptr;
        
        PRUint32 offset;
    
      } data;
    };

    NS_IMETHODIMP nsHTMLFrameElement::QueryInterface(REFNSIID aIID, void **aResult)
    {
      
        #ifdef DEBUG
        static const nsID kGQI_nsINode = { 0xd1c2e967, 0x854a, 0x436b, { 0xbf, 0xa5, 0xf6, 0xa4, 0x9a, 0x97, 0x46, 0x74 } };
        NS_ASSERTION(NS_GET_IID(nsINode).Equals(kGQI_nsINode),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMEventTarget = { 0x44a6597b, 0x9fc3, 0x4a8d, { 0xb7, 0xa4, 0xd9, 0x00, 0x9a, 0xbf, 0x9d, 0x15 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMEventTarget).Equals(kGQI_nsPIDOMEventTarget),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIContent = { 0xfba9aa39, 0x016e, 0x4d5d, { 0xab, 0x62, 0x22, 0xa1, 0xb8, 0x4a, 0x3c, 0x7b } };
        NS_ASSERTION(NS_GET_IID(nsIContent).Equals(kGQI_nsIContent),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionParticipant = { 0x9674489b, 0x1f6f, 0x4550, { 0xa7, 0x30, 0xcc, 0xae, 0xdd, 0x10, 0x4c, 0xf9 } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionParticipant).Equals(kGQI_nsCycleCollectionParticipant),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionISupports = { 0xc61eac14, 0x5f7a, 0x4481, { 0x96, 0x5e, 0x7e, 0xaa, 0x6e, 0xff, 0xa8, 0x5f } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionISupports).Equals(kGQI_nsCycleCollectionISupports),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIClassInfo = { 0x986c11d0, 0xf340, 0x11d4, { 0x90, 0x75, 0x00, 0x10, 0xa4, 0xe7, 0x3d, 0x9a } };
        NS_ASSERTION(NS_GET_IID(nsIClassInfo).Equals(kGQI_nsIClassInfo),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        

      static const PRUint8 kLookupTable[] = {
#ifdef IS_BIG_ENDIAN
        10,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
20,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
0,
0xFF,
0xFF,
0xFF,
16,
11,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
15,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
3,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
19,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
6,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
4,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
9,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF
#else
        10,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
20,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
0,
0xFF,
0xFF,
0xFF,
16,
11,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
15,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
3,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
19,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
6,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
4,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
9,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF
#endif
      };

      static const nsHTMLFrameElement_QIAction kActionTable[] = {
        
        {
          &(NS_GET_IID(nsIDOMNode)),
          nsHTMLFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNode*>(((nsHTMLFrameElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLFrameElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsINode)),
          nsHTMLFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsINode*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000)))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMElement)),
          nsHTMLFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMElement*>(((nsHTMLFrameElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLFrameElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsPIDOMEventTarget)),
          nsHTMLFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMEventTarget*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000)))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIContent)),
          nsHTMLFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000)))))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionParticipant)),
          nsHTMLFrameElement_STATIC_POINTER,
          { &NS_CYCLE_COLLECTION_NAME(nsHTMLFrameElement) }
        },
    
        {
          &(NS_GET_IID(nsIDOM3Node)),
          nsHTMLFrameElement_NS_TEAROFF_nsIDOM3Node,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLElement)),
          nsHTMLFrameElement_NS_TEAROFF_nsIDOMNSHTMLElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMElementCSSInlineStyle)),
          nsHTMLFrameElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIFrameLoaderOwner)),
          nsHTMLFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIFrameLoaderOwner*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsISupports)),
          nsHTMLFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupports*>(
           static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000)))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000)))))))
   }
        },
    
        {
          &(NS_GET_IID(nsISupportsWeakReference)),
          nsHTMLFrameElement_NS_TEAROFF_nsISupportsWeakReference,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLFrameElement)),
          nsHTMLFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMEventTarget)),
          nsHTMLFrameElement_NS_TEAROFF_nsIDOMEventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOM3EventTarget)),
          nsHTMLFrameElement_NS_TEAROFF_nsIDOM3EventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSElement)),
          nsHTMLFrameElement_NS_TEAROFF_nsIDOMNSElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLElement)),
          nsHTMLFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLElement*>(((nsHTMLFrameElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLFrameElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionISupports)),
          nsHTMLFrameElement_CC_ISUPPORTS,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLFrameElement)),
          nsHTMLFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSHTMLFrameElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLFrameElement*>(((nsHTMLFrameElement*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIClassInfo)),
          nsHTMLFrameElement_DOMCI,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSEventTarget)),
          nsHTMLFrameElement_NS_TEAROFF_nsIDOMNSEventTarget,
          {0}
        },
    
      };

      nsISupports* found = nsnull;
      const nsHTMLFrameElement_QIAction *entry;
      PRUint32 index =
#ifdef IS_BIG_ENDIAN
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x3fe) >> 1;
#else
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x3fe) >> 1;
#endif

      PRUint8 action = kLookupTable[index];
      if (action == 0xFF)
        goto unfound;

      entry = kActionTable + action;
      if (!entry->iid->Equals(aIID))
        goto unfound;

      
      switch (entry->action) {
      
      case nsHTMLFrameElement_OFFSET_THIS_ADDREF:
        
        found = reinterpret_cast<nsISupports*>(reinterpret_cast<char*>(this) + entry->data.offset);
        goto exit_addref;
    
    
      case nsHTMLFrameElement_NS_TEAROFF_nsIDOMNSElement:
        
            found = static_cast<nsIDOMNSElement*>(new nsNSElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameElement_NS_TEAROFF_nsISupportsWeakReference:
        
            found = static_cast<nsISupportsWeakReference*>(new nsNodeSupportsWeakRefTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameElement_NS_TEAROFF_nsIDOMNSHTMLElement:
        
            found = static_cast<nsIDOMNSHTMLElement*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle:
        
            found = static_cast<nsIDOMElementCSSInlineStyle*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameElement_CC_ISUPPORTS:
        
        found = NS_CYCLE_COLLECTION_CLASSNAME(nsHTMLFrameElement)::Upcast(this);
        goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameElement_DOMCI:
        
      found = NS_GetDOMClassInfoInstance(eDOMClassInfo_HTMLFrameElement_id);
      goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameElement_STATIC_POINTER:
        *aResult = entry->data.ptr;
                   return NS_OK;
    
      case nsHTMLFrameElement_NS_TEAROFF_nsIDOM3Node:
        
            found = static_cast<nsIDOM3Node*>(new nsNode3Tearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameElement_NS_TEAROFF_nsIDOMNSEventTarget:
        
            found = static_cast<nsIDOMNSEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameElement_NS_TEAROFF_nsIDOM3EventTarget:
        
            found = static_cast<nsIDOM3EventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLFrameElement_NS_TEAROFF_nsIDOMEventTarget:
        
            found = static_cast<nsIDOMEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      }
    

      NS_NOTREACHED("Unhandled case?");

      
    exit_nullcheck_addref:
      if (!found)
        return NS_ERROR_OUT_OF_MEMORY;
    

    exit_addref:
      NS_ASSERTION(found, "Interface should have been found by now.");
      found->AddRef();
      *aResult = found;
      return NS_OK;

    unfound:
      return PostQueryInterface(aIID, aResult);
    }

    enum nsHTMLAnchorElement_QIActionType {
      nsHTMLAnchorElement_OFFSET_THIS_ADDREF, nsHTMLAnchorElement_NS_TEAROFF_nsIDOMNSElement, nsHTMLAnchorElement_NS_TEAROFF_nsISupportsWeakReference, nsHTMLAnchorElement_NS_TEAROFF_nsIDOMNSHTMLElement, nsHTMLAnchorElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle, nsHTMLAnchorElement_CC_ISUPPORTS, nsHTMLAnchorElement_DOMCI, nsHTMLAnchorElement_STATIC_POINTER, nsHTMLAnchorElement_NS_TEAROFF_nsIDOM3Node, nsHTMLAnchorElement_NS_TEAROFF_nsIDOMNSEventTarget, nsHTMLAnchorElement_NS_TEAROFF_nsIDOM3EventTarget, nsHTMLAnchorElement_NS_TEAROFF_nsIDOMEventTarget
    };

    struct nsHTMLAnchorElement_QIAction {
      const nsID *iid;
      nsHTMLAnchorElement_QIActionType action;
      union {
        void *ptr;
        
        PRUint32 offset;
    
      } data;
    };

    NS_IMETHODIMP nsHTMLAnchorElement::QueryInterface(REFNSIID aIID, void **aResult)
    {
      
        #ifdef DEBUG
        static const nsID kGQI_nsINode = { 0xd1c2e967, 0x854a, 0x436b, { 0xbf, 0xa5, 0xf6, 0xa4, 0x9a, 0x97, 0x46, 0x74 } };
        NS_ASSERTION(NS_GET_IID(nsINode).Equals(kGQI_nsINode),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMEventTarget = { 0x44a6597b, 0x9fc3, 0x4a8d, { 0xb7, 0xa4, 0xd9, 0x00, 0x9a, 0xbf, 0x9d, 0x15 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMEventTarget).Equals(kGQI_nsPIDOMEventTarget),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionParticipant = { 0x9674489b, 0x1f6f, 0x4550, { 0xa7, 0x30, 0xcc, 0xae, 0xdd, 0x10, 0x4c, 0xf9 } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionParticipant).Equals(kGQI_nsCycleCollectionParticipant),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIContent = { 0xfba9aa39, 0x016e, 0x4d5d, { 0xab, 0x62, 0x22, 0xa1, 0xb8, 0x4a, 0x3c, 0x7b } };
        NS_ASSERTION(NS_GET_IID(nsIContent).Equals(kGQI_nsIContent),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsILink = { 0x0c212bc4, 0xfcd7, 0x479d, { 0x8c, 0x3f, 0x3b, 0xe8, 0xe6, 0x78, 0x74, 0x50 } };
        NS_ASSERTION(NS_GET_IID(nsILink).Equals(kGQI_nsILink),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIClassInfo = { 0x986c11d0, 0xf340, 0x11d4, { 0x90, 0x75, 0x00, 0x10, 0xa4, 0xe7, 0x3d, 0x9a } };
        NS_ASSERTION(NS_GET_IID(nsIClassInfo).Equals(kGQI_nsIClassInfo),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionISupports = { 0xc61eac14, 0x5f7a, 0x4481, { 0x96, 0x5e, 0x7e, 0xaa, 0x6e, 0xff, 0xa8, 0x5f } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionISupports).Equals(kGQI_nsCycleCollectionISupports),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        

      static const PRUint8 kLookupTable[] = {
#ifdef IS_BIG_ENDIAN
        9,
0xFF,
0xFF,
0xFF,
0xFF,
15,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
20,
0xFF,
0xFF,
0xFF,
6,
10,
0xFF,
11,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
21,
0xFF,
0xFF,
4,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
19,
0xFF,
0xFF,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
16,
0xFF,
0xFF,
3,
0,
0xFF,
0xFF,
0xFF
#else
        9,
0xFF,
0xFF,
0xFF,
0xFF,
15,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
20,
0xFF,
0xFF,
0xFF,
6,
10,
0xFF,
11,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
21,
0xFF,
0xFF,
4,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
19,
0xFF,
0xFF,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
16,
0xFF,
0xFF,
3,
0,
0xFF,
0xFF,
0xFF
#endif
      };

      static const nsHTMLAnchorElement_QIAction kActionTable[] = {
        
        {
          &(NS_GET_IID(nsIDOMNode)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNode*>(((nsHTMLAnchorElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLAnchorElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsINode)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsINode*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLAnchorElement2)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSHTMLAnchorElement2*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsPIDOMEventTarget)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMEventTarget*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLAnchorElement)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLAnchorElement*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSEventTarget)),
          nsHTMLAnchorElement_NS_TEAROFF_nsIDOMNSEventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOM3Node)),
          nsHTMLAnchorElement_NS_TEAROFF_nsIDOM3Node,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLElement)),
          nsHTMLAnchorElement_NS_TEAROFF_nsIDOMNSHTMLElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMElementCSSInlineStyle)),
          nsHTMLAnchorElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupports)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupports*>(
           static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSElement)),
          nsHTMLAnchorElement_NS_TEAROFF_nsIDOMNSElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionParticipant)),
          nsHTMLAnchorElement_STATIC_POINTER,
          { &NS_CYCLE_COLLECTION_NAME(nsHTMLAnchorElement) }
        },
    
        {
          &(NS_GET_IID(nsIDOMEventTarget)),
          nsHTMLAnchorElement_NS_TEAROFF_nsIDOMEventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupportsWeakReference)),
          nsHTMLAnchorElement_NS_TEAROFF_nsISupportsWeakReference,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLAnchorElement)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSHTMLAnchorElement*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLElement)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLElement*>(((nsHTMLAnchorElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLAnchorElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMElement)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMElement*>(((nsHTMLAnchorElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLAnchorElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsIContent)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsILink)),
          nsHTMLAnchorElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsILink*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLAnchorElement*>(((nsHTMLAnchorElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIClassInfo)),
          nsHTMLAnchorElement_DOMCI,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionISupports)),
          nsHTMLAnchorElement_CC_ISUPPORTS,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOM3EventTarget)),
          nsHTMLAnchorElement_NS_TEAROFF_nsIDOM3EventTarget,
          {0}
        },
    
      };

      nsISupports* found = nsnull;
      const nsHTMLAnchorElement_QIAction *entry;
      PRUint32 index =
#ifdef IS_BIG_ENDIAN
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#else
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#endif

      PRUint8 action = kLookupTable[index];
      if (action == 0xFF)
        goto unfound;

      entry = kActionTable + action;
      if (!entry->iid->Equals(aIID))
        goto unfound;

      
      switch (entry->action) {
      
      case nsHTMLAnchorElement_OFFSET_THIS_ADDREF:
        
        found = reinterpret_cast<nsISupports*>(reinterpret_cast<char*>(this) + entry->data.offset);
        goto exit_addref;
    
    
      case nsHTMLAnchorElement_NS_TEAROFF_nsIDOMNSElement:
        
            found = static_cast<nsIDOMNSElement*>(new nsNSElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLAnchorElement_NS_TEAROFF_nsISupportsWeakReference:
        
            found = static_cast<nsISupportsWeakReference*>(new nsNodeSupportsWeakRefTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLAnchorElement_NS_TEAROFF_nsIDOMNSHTMLElement:
        
            found = static_cast<nsIDOMNSHTMLElement*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLAnchorElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle:
        
            found = static_cast<nsIDOMElementCSSInlineStyle*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLAnchorElement_CC_ISUPPORTS:
        
        found = NS_CYCLE_COLLECTION_CLASSNAME(nsHTMLAnchorElement)::Upcast(this);
        goto exit_nullcheck_addref;
    
    
      case nsHTMLAnchorElement_DOMCI:
        
      found = NS_GetDOMClassInfoInstance(eDOMClassInfo_HTMLAnchorElement_id);
      goto exit_nullcheck_addref;
    
    
      case nsHTMLAnchorElement_STATIC_POINTER:
        *aResult = entry->data.ptr;
                   return NS_OK;
    
      case nsHTMLAnchorElement_NS_TEAROFF_nsIDOM3Node:
        
            found = static_cast<nsIDOM3Node*>(new nsNode3Tearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLAnchorElement_NS_TEAROFF_nsIDOMNSEventTarget:
        
            found = static_cast<nsIDOMNSEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLAnchorElement_NS_TEAROFF_nsIDOM3EventTarget:
        
            found = static_cast<nsIDOM3EventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLAnchorElement_NS_TEAROFF_nsIDOMEventTarget:
        
            found = static_cast<nsIDOMEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      }
    

      NS_NOTREACHED("Unhandled case?");

      
    exit_nullcheck_addref:
      if (!found)
        return NS_ERROR_OUT_OF_MEMORY;
    

    exit_addref:
      NS_ASSERTION(found, "Interface should have been found by now.");
      found->AddRef();
      *aResult = found;
      return NS_OK;

    unfound:
      return PostQueryInterface(aIID, aResult);
    }

    enum nsHTMLIFrameElement_QIActionType {
      nsHTMLIFrameElement_OFFSET_THIS_ADDREF, nsHTMLIFrameElement_NS_TEAROFF_nsIDOMNSElement, nsHTMLIFrameElement_NS_TEAROFF_nsISupportsWeakReference, nsHTMLIFrameElement_NS_TEAROFF_nsIDOMNSHTMLElement, nsHTMLIFrameElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle, nsHTMLIFrameElement_CC_ISUPPORTS, nsHTMLIFrameElement_DOMCI, nsHTMLIFrameElement_STATIC_POINTER, nsHTMLIFrameElement_NS_TEAROFF_nsIDOM3Node, nsHTMLIFrameElement_NS_TEAROFF_nsIDOMNSEventTarget, nsHTMLIFrameElement_NS_TEAROFF_nsIDOM3EventTarget, nsHTMLIFrameElement_NS_TEAROFF_nsIDOMEventTarget
    };

    struct nsHTMLIFrameElement_QIAction {
      const nsID *iid;
      nsHTMLIFrameElement_QIActionType action;
      union {
        void *ptr;
        
        PRUint32 offset;
    
      } data;
    };

    NS_IMETHODIMP nsHTMLIFrameElement::QueryInterface(REFNSIID aIID, void **aResult)
    {
      
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMEventTarget = { 0x44a6597b, 0x9fc3, 0x4a8d, { 0xb7, 0xa4, 0xd9, 0x00, 0x9a, 0xbf, 0x9d, 0x15 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMEventTarget).Equals(kGQI_nsPIDOMEventTarget),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIContent = { 0xfba9aa39, 0x016e, 0x4d5d, { 0xab, 0x62, 0x22, 0xa1, 0xb8, 0x4a, 0x3c, 0x7b } };
        NS_ASSERTION(NS_GET_IID(nsIContent).Equals(kGQI_nsIContent),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionParticipant = { 0x9674489b, 0x1f6f, 0x4550, { 0xa7, 0x30, 0xcc, 0xae, 0xdd, 0x10, 0x4c, 0xf9 } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionParticipant).Equals(kGQI_nsCycleCollectionParticipant),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsINode = { 0xd1c2e967, 0x854a, 0x436b, { 0xbf, 0xa5, 0xf6, 0xa4, 0x9a, 0x97, 0x46, 0x74 } };
        NS_ASSERTION(NS_GET_IID(nsINode).Equals(kGQI_nsINode),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionISupports = { 0xc61eac14, 0x5f7a, 0x4481, { 0x96, 0x5e, 0x7e, 0xaa, 0x6e, 0xff, 0xa8, 0x5f } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionISupports).Equals(kGQI_nsCycleCollectionISupports),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIClassInfo = { 0x986c11d0, 0xf340, 0x11d4, { 0x90, 0x75, 0x00, 0x10, 0xa4, 0xe7, 0x3d, 0x9a } };
        NS_ASSERTION(NS_GET_IID(nsIClassInfo).Equals(kGQI_nsIClassInfo),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        

      static const PRUint8 kLookupTable[] = {
#ifdef IS_BIG_ENDIAN
        10,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
20,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
1,
0xFF,
0xFF,
0xFF,
16,
15,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
9,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
11,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
3,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
19,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
6,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
4,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF
#else
        10,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
20,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
1,
0xFF,
0xFF,
0xFF,
16,
15,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
9,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
11,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
3,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
19,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
6,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
4,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF
#endif
      };

      static const nsHTMLIFrameElement_QIAction kActionTable[] = {
        
        {
          &(NS_GET_IID(nsIDOMHTMLIFrameElement)),
          nsHTMLIFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLIFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNode)),
          nsHTMLIFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNode*>(((nsHTMLIFrameElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLIFrameElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMElement)),
          nsHTMLIFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMElement*>(((nsHTMLIFrameElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLIFrameElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsPIDOMEventTarget)),
          nsHTMLIFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMEventTarget*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000)))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIContent)),
          nsHTMLIFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000)))))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionParticipant)),
          nsHTMLIFrameElement_STATIC_POINTER,
          { &NS_CYCLE_COLLECTION_NAME(nsHTMLIFrameElement) }
        },
    
        {
          &(NS_GET_IID(nsIDOM3Node)),
          nsHTMLIFrameElement_NS_TEAROFF_nsIDOM3Node,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLElement)),
          nsHTMLIFrameElement_NS_TEAROFF_nsIDOMNSHTMLElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMElementCSSInlineStyle)),
          nsHTMLIFrameElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSElement)),
          nsHTMLIFrameElement_NS_TEAROFF_nsIDOMNSElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupports)),
          nsHTMLIFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupports*>(
           static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000)))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000)))))))
   }
        },
    
        {
          &(NS_GET_IID(nsINode)),
          nsHTMLIFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsINode*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000)))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIFrameLoaderOwner)),
          nsHTMLIFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIFrameLoaderOwner*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMEventTarget)),
          nsHTMLIFrameElement_NS_TEAROFF_nsIDOMEventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOM3EventTarget)),
          nsHTMLIFrameElement_NS_TEAROFF_nsIDOM3EventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupportsWeakReference)),
          nsHTMLIFrameElement_NS_TEAROFF_nsISupportsWeakReference,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLElement)),
          nsHTMLIFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLElement*>(((nsHTMLIFrameElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLIFrameElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionISupports)),
          nsHTMLIFrameElement_CC_ISUPPORTS,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLFrameElement)),
          nsHTMLIFrameElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSHTMLFrameElement*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsGenericHTMLFrameElement*>(static_cast<nsHTMLIFrameElement*>(((nsHTMLIFrameElement*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIClassInfo)),
          nsHTMLIFrameElement_DOMCI,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSEventTarget)),
          nsHTMLIFrameElement_NS_TEAROFF_nsIDOMNSEventTarget,
          {0}
        },
    
      };

      nsISupports* found = nsnull;
      const nsHTMLIFrameElement_QIAction *entry;
      PRUint32 index =
#ifdef IS_BIG_ENDIAN
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x3fe) >> 1;
#else
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x3fe) >> 1;
#endif

      PRUint8 action = kLookupTable[index];
      if (action == 0xFF)
        goto unfound;

      entry = kActionTable + action;
      if (!entry->iid->Equals(aIID))
        goto unfound;

      
      switch (entry->action) {
      
      case nsHTMLIFrameElement_OFFSET_THIS_ADDREF:
        
        found = reinterpret_cast<nsISupports*>(reinterpret_cast<char*>(this) + entry->data.offset);
        goto exit_addref;
    
    
      case nsHTMLIFrameElement_NS_TEAROFF_nsIDOMNSElement:
        
            found = static_cast<nsIDOMNSElement*>(new nsNSElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLIFrameElement_NS_TEAROFF_nsISupportsWeakReference:
        
            found = static_cast<nsISupportsWeakReference*>(new nsNodeSupportsWeakRefTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLIFrameElement_NS_TEAROFF_nsIDOMNSHTMLElement:
        
            found = static_cast<nsIDOMNSHTMLElement*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLIFrameElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle:
        
            found = static_cast<nsIDOMElementCSSInlineStyle*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLIFrameElement_CC_ISUPPORTS:
        
        found = NS_CYCLE_COLLECTION_CLASSNAME(nsHTMLIFrameElement)::Upcast(this);
        goto exit_nullcheck_addref;
    
    
      case nsHTMLIFrameElement_DOMCI:
        
      found = NS_GetDOMClassInfoInstance(eDOMClassInfo_HTMLIFrameElement_id);
      goto exit_nullcheck_addref;
    
    
      case nsHTMLIFrameElement_STATIC_POINTER:
        *aResult = entry->data.ptr;
                   return NS_OK;
    
      case nsHTMLIFrameElement_NS_TEAROFF_nsIDOM3Node:
        
            found = static_cast<nsIDOM3Node*>(new nsNode3Tearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLIFrameElement_NS_TEAROFF_nsIDOMNSEventTarget:
        
            found = static_cast<nsIDOMNSEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLIFrameElement_NS_TEAROFF_nsIDOM3EventTarget:
        
            found = static_cast<nsIDOM3EventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLIFrameElement_NS_TEAROFF_nsIDOMEventTarget:
        
            found = static_cast<nsIDOMEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      }
    

      NS_NOTREACHED("Unhandled case?");

      
    exit_nullcheck_addref:
      if (!found)
        return NS_ERROR_OUT_OF_MEMORY;
    

    exit_addref:
      NS_ASSERTION(found, "Interface should have been found by now.");
      found->AddRef();
      *aResult = found;
      return NS_OK;

    unfound:
      return PostQueryInterface(aIID, aResult);
    }

    enum nsHTMLSpanElement_QIActionType {
      nsHTMLSpanElement_OFFSET_THIS_ADDREF, nsHTMLSpanElement_NS_TEAROFF_nsIDOMNSElement, nsHTMLSpanElement_NS_TEAROFF_nsISupportsWeakReference, nsHTMLSpanElement_NS_TEAROFF_nsIDOMNSHTMLElement, nsHTMLSpanElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle, nsHTMLSpanElement_CC_ISUPPORTS, nsHTMLSpanElement_DOMCI, nsHTMLSpanElement_STATIC_POINTER, nsHTMLSpanElement_NS_TEAROFF_nsIDOM3Node, nsHTMLSpanElement_NS_TEAROFF_nsIDOMNSEventTarget, nsHTMLSpanElement_NS_TEAROFF_nsIDOM3EventTarget, nsHTMLSpanElement_NS_TEAROFF_nsIDOMEventTarget
    };

    struct nsHTMLSpanElement_QIAction {
      const nsID *iid;
      nsHTMLSpanElement_QIActionType action;
      union {
        void *ptr;
        
        PRUint32 offset;
    
      } data;
    };

    NS_IMETHODIMP nsHTMLSpanElement::QueryInterface(REFNSIID aIID, void **aResult)
    {
      
        #ifdef DEBUG
        static const nsID kGQI_nsINode = { 0xd1c2e967, 0x854a, 0x436b, { 0xbf, 0xa5, 0xf6, 0xa4, 0x9a, 0x97, 0x46, 0x74 } };
        NS_ASSERTION(NS_GET_IID(nsINode).Equals(kGQI_nsINode),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMEventTarget = { 0x44a6597b, 0x9fc3, 0x4a8d, { 0xb7, 0xa4, 0xd9, 0x00, 0x9a, 0xbf, 0x9d, 0x15 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMEventTarget).Equals(kGQI_nsPIDOMEventTarget),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIContent = { 0xfba9aa39, 0x016e, 0x4d5d, { 0xab, 0x62, 0x22, 0xa1, 0xb8, 0x4a, 0x3c, 0x7b } };
        NS_ASSERTION(NS_GET_IID(nsIContent).Equals(kGQI_nsIContent),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionParticipant = { 0x9674489b, 0x1f6f, 0x4550, { 0xa7, 0x30, 0xcc, 0xae, 0xdd, 0x10, 0x4c, 0xf9 } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionParticipant).Equals(kGQI_nsCycleCollectionParticipant),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionISupports = { 0xc61eac14, 0x5f7a, 0x4481, { 0x96, 0x5e, 0x7e, 0xaa, 0x6e, 0xff, 0xa8, 0x5f } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionISupports).Equals(kGQI_nsCycleCollectionISupports),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIClassInfo = { 0x986c11d0, 0xf340, 0x11d4, { 0x90, 0x75, 0x00, 0x10, 0xa4, 0xe7, 0x3d, 0x9a } };
        NS_ASSERTION(NS_GET_IID(nsIClassInfo).Equals(kGQI_nsIClassInfo),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        

      static const PRUint8 kLookupTable[] = {
#ifdef IS_BIG_ENDIAN
        9,
0xFF,
0xFF,
0xFF,
0xFF,
14,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
15,
0xFF,
0xFF,
0xFF,
6,
10,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
11,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
4,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
16,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
0xFF,
3,
0,
0xFF,
0xFF,
0xFF
#else
        9,
0xFF,
0xFF,
0xFF,
0xFF,
14,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
15,
0xFF,
0xFF,
0xFF,
6,
10,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
12,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
11,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
4,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
16,
0xFF,
0xFF,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
0xFF,
3,
0,
0xFF,
0xFF,
0xFF
#endif
      };

      static const nsHTMLSpanElement_QIAction kActionTable[] = {
        
        {
          &(NS_GET_IID(nsIDOMNode)),
          nsHTMLSpanElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNode*>(((nsHTMLSpanElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLSpanElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsINode)),
          nsHTMLSpanElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsINode*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLSpanElement*>(((nsHTMLSpanElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLSpanElement*>(((nsHTMLSpanElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMElement)),
          nsHTMLSpanElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMElement*>(((nsHTMLSpanElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLSpanElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsPIDOMEventTarget)),
          nsHTMLSpanElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMEventTarget*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLSpanElement*>(((nsHTMLSpanElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLSpanElement*>(((nsHTMLSpanElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIContent)),
          nsHTMLSpanElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLSpanElement*>(((nsHTMLSpanElement*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLSpanElement*>(((nsHTMLSpanElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionParticipant)),
          nsHTMLSpanElement_STATIC_POINTER,
          { &NS_CYCLE_COLLECTION_NAME(nsHTMLSpanElement) }
        },
    
        {
          &(NS_GET_IID(nsIDOM3Node)),
          nsHTMLSpanElement_NS_TEAROFF_nsIDOM3Node,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLElement)),
          nsHTMLSpanElement_NS_TEAROFF_nsIDOMNSHTMLElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMElementCSSInlineStyle)),
          nsHTMLSpanElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupports)),
          nsHTMLSpanElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupports*>(
           static_cast<nsIContent*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLSpanElement*>(((nsHTMLSpanElement*) 0x1000))))))) -
       reinterpret_cast<char*>(static_cast<nsGenericElement*>(static_cast<nsGenericHTMLElement*>(static_cast<nsHTMLSpanElement*>(((nsHTMLSpanElement*) 0x1000))))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSElement)),
          nsHTMLSpanElement_NS_TEAROFF_nsIDOMNSElement,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMEventTarget)),
          nsHTMLSpanElement_NS_TEAROFF_nsIDOMEventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOM3EventTarget)),
          nsHTMLSpanElement_NS_TEAROFF_nsIDOM3EventTarget,
          {0}
        },
    
        {
          &(NS_GET_IID(nsISupportsWeakReference)),
          nsHTMLSpanElement_NS_TEAROFF_nsISupportsWeakReference,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLElement)),
          nsHTMLSpanElement_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLElement*>(((nsHTMLSpanElement*) 0x1000))) -
       reinterpret_cast<char*>(((nsHTMLSpanElement*) 0x1000)))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionISupports)),
          nsHTMLSpanElement_CC_ISUPPORTS,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIClassInfo)),
          nsHTMLSpanElement_DOMCI,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSEventTarget)),
          nsHTMLSpanElement_NS_TEAROFF_nsIDOMNSEventTarget,
          {0}
        },
    
      };

      nsISupports* found = nsnull;
      const nsHTMLSpanElement_QIAction *entry;
      PRUint32 index =
#ifdef IS_BIG_ENDIAN
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#else
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#endif

      PRUint8 action = kLookupTable[index];
      if (action == 0xFF)
        goto unfound;

      entry = kActionTable + action;
      if (!entry->iid->Equals(aIID))
        goto unfound;

      
      switch (entry->action) {
      
      case nsHTMLSpanElement_OFFSET_THIS_ADDREF:
        
        found = reinterpret_cast<nsISupports*>(reinterpret_cast<char*>(this) + entry->data.offset);
        goto exit_addref;
    
    
      case nsHTMLSpanElement_NS_TEAROFF_nsIDOMNSElement:
        
            found = static_cast<nsIDOMNSElement*>(new nsNSElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLSpanElement_NS_TEAROFF_nsISupportsWeakReference:
        
            found = static_cast<nsISupportsWeakReference*>(new nsNodeSupportsWeakRefTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLSpanElement_NS_TEAROFF_nsIDOMNSHTMLElement:
        
            found = static_cast<nsIDOMNSHTMLElement*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLSpanElement_NS_TEAROFF_nsIDOMElementCSSInlineStyle:
        
            found = static_cast<nsIDOMElementCSSInlineStyle*>(new nsGenericHTMLElementTearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLSpanElement_CC_ISUPPORTS:
        
        found = NS_CYCLE_COLLECTION_CLASSNAME(nsHTMLSpanElement)::Upcast(this);
        goto exit_nullcheck_addref;
    
    
      case nsHTMLSpanElement_DOMCI:
        
      found = NS_GetDOMClassInfoInstance(eDOMClassInfo_HTMLSpanElement_id);
      goto exit_nullcheck_addref;
    
    
      case nsHTMLSpanElement_STATIC_POINTER:
        *aResult = entry->data.ptr;
                   return NS_OK;
    
      case nsHTMLSpanElement_NS_TEAROFF_nsIDOM3Node:
        
            found = static_cast<nsIDOM3Node*>(new nsNode3Tearoff(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLSpanElement_NS_TEAROFF_nsIDOMNSEventTarget:
        
            found = static_cast<nsIDOMNSEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLSpanElement_NS_TEAROFF_nsIDOM3EventTarget:
        
            found = static_cast<nsIDOM3EventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      case nsHTMLSpanElement_NS_TEAROFF_nsIDOMEventTarget:
        
            found = static_cast<nsIDOMEventTarget*>(nsDOMEventRTTearoff::Create(this));
            goto exit_nullcheck_addref;
    
    
      }
    

      NS_NOTREACHED("Unhandled case?");

      
    exit_nullcheck_addref:
      if (!found)
        return NS_ERROR_OUT_OF_MEMORY;
    

    exit_addref:
      NS_ASSERTION(found, "Interface should have been found by now.");
      found->AddRef();
      *aResult = found;
      return NS_OK;

    unfound:
      return PostQueryInterface(aIID, aResult);
    }
