#include "nsIDOM3Node.h"
#include "nsIDOMNSElement.h"
#include "nsIDOMEventTarget.h"
#include "nsIDOM3EventTarget.h"
#include "nsIDOMNSEventTarget.h"
#include "nsIWeakReference.h"
#include "nsIDOMDocument.h"
#include "nsIDOM3Document.h"
#include "nsIDOMNSDocument.h"
#include "nsIDOMDocumentEvent.h"
#include "nsIDOM3DocumentEvent.h"
#include "nsIDOMDocumentStyle.h"
#include "nsIDOMNSDocumentStyle.h"
#include "nsIDOMDocumentView.h"
#include "nsIDOMDocumentRange.h"
#include "nsIDOMDocumentTraversal.h"
#include "nsIDOMDocumentXBL.h"
#include "nsIDOMXPathEvaluator.h"
#include "nsGenericElement.h"
#include "nsDocument.h"
#include "nsIXPathEvaluatorInternal.h"
#include "nsDOMCID.h"
#include "nsComponentManagerUtils.h"
#include "nsIDOMHTMLDocument.h"
#include "nsIDOMNSHTMLDocument.h"
#include "nsHTMLDocument.h"

    enum nsHTMLDocument_QIActionType {
      nsHTMLDocument_OFFSET_THIS_ADDREF, nsHTMLDocument_DOMCI, nsHTMLDocument_LITERAL_CODE_nsIDOMXPathEvaluator, nsHTMLDocument_STATIC_POINTER, nsHTMLDocument_CC_ISUPPORTS
    };

    struct nsHTMLDocument_QIAction {
      const nsID *iid;
      nsHTMLDocument_QIActionType action;
      union {
        void *ptr;
        
        PRUint32 offset;
    
      } data;
    };

    NS_IMETHODIMP nsHTMLDocument::QueryInterface(REFNSIID aIID, void **aResult)
    {
      
        #ifdef DEBUG
        static const nsID kGQI_nsINode = { 0xd1c2e967, 0x854a, 0x436b, { 0xbf, 0xa5, 0xf6, 0xa4, 0x9a, 0x97, 0x46, 0x74 } };
        NS_ASSERTION(NS_GET_IID(nsINode).Equals(kGQI_nsINode),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMEventTarget = { 0x44a6597b, 0x9fc3, 0x4a8d, { 0xb7, 0xa4, 0xd9, 0x00, 0x9a, 0xbf, 0x9d, 0x15 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMEventTarget).Equals(kGQI_nsPIDOMEventTarget),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIScriptObjectPrincipal = { 0x3eedba38, 0x8d22, 0x41e1, { 0x81, 0x7a, 0x0e, 0x43, 0xe1, 0x65, 0xb6, 0x64 } };
        NS_ASSERTION(NS_GET_IID(nsIScriptObjectPrincipal).Equals(kGQI_nsIScriptObjectPrincipal),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIMutationObserver = { 0x32e68316, 0x67d4, 0x44a5, { 0x8d, 0x35, 0x0d, 0x39, 0x0f, 0xa9, 0xdf, 0x11 } };
        NS_ASSERTION(NS_GET_IID(nsIMutationObserver).Equals(kGQI_nsIMutationObserver),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIXPathEvaluatorInternal = { 0xb4b72daa, 0x65d6, 0x440f, { 0xb6, 0x08, 0xe2, 0xee, 0x9a, 0x82, 0xf3, 0x13 } };
        NS_ASSERTION(NS_GET_IID(nsIXPathEvaluatorInternal).Equals(kGQI_nsIXPathEvaluatorInternal),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionParticipant = { 0x9674489b, 0x1f6f, 0x4550, { 0xa7, 0x30, 0xcc, 0xae, 0xdd, 0x10, 0x4c, 0xf9 } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionParticipant).Equals(kGQI_nsCycleCollectionParticipant),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIDocument = { 0x626d86d2, 0x615f, 0x4a12, { 0x94, 0xd8, 0xe3, 0xdb, 0x3a, 0x29, 0x83, 0x72 } };
        NS_ASSERTION(NS_GET_IID(nsIDocument).Equals(kGQI_nsIDocument),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIHTMLDocument = { 0x61e989a8, 0x70cd, 0x4582, { 0x84, 0x5e, 0x6e, 0x5e, 0x12, 0x55, 0x9a, 0x83 } };
        NS_ASSERTION(NS_GET_IID(nsIHTMLDocument).Equals(kGQI_nsIHTMLDocument),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIClassInfo = { 0x986c11d0, 0xf340, 0x11d4, { 0x90, 0x75, 0x00, 0x10, 0xa4, 0xe7, 0x3d, 0x9a } };
        NS_ASSERTION(NS_GET_IID(nsIClassInfo).Equals(kGQI_nsIClassInfo),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIRadioGroupContainer = { 0x06de7839, 0xd0db, 0x47d3, { 0x82, 0x90, 0x3c, 0xb8, 0x62, 0x2e, 0xd9, 0x66 } };
        NS_ASSERTION(NS_GET_IID(nsIRadioGroupContainer).Equals(kGQI_nsIRadioGroupContainer),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionISupports = { 0xc61eac14, 0x5f7a, 0x4481, { 0x96, 0x5e, 0x7e, 0xaa, 0x6e, 0xff, 0xa8, 0x5f } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionISupports).Equals(kGQI_nsCycleCollectionISupports),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        

      static const PRUint8 kLookupTable[] = {
#ifdef IS_BIG_ENDIAN
        11,
0xFF,
0xFF,
0xFF,
3,
0xFF,
31,
0xFF,
0xFF,
22,
23,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
16,
0xFF,
0xFF,
0xFF,
29,
0xFF,
6,
0xFF,
9,
15,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
30,
21,
0xFF,
12,
24,
0xFF,
0xFF,
0xFF,
0xFF,
20,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
4,
28,
18,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
27,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
26,
0xFF,
19,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
10,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
25,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0,
0xFF,
0xFF,
0xFF
#else
        11,
0xFF,
0xFF,
0xFF,
3,
0xFF,
31,
0xFF,
0xFF,
22,
23,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
16,
0xFF,
0xFF,
0xFF,
29,
0xFF,
6,
0xFF,
9,
15,
0xFF,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
14,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
30,
21,
0xFF,
12,
24,
0xFF,
0xFF,
0xFF,
0xFF,
20,
13,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
4,
28,
18,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
27,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
7,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
26,
0xFF,
19,
0xFF,
5,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
10,
1,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
8,
0xFF,
25,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0,
0xFF,
0xFF,
0xFF
#endif
      };

      static const nsHTMLDocument_QIAction kActionTable[] = {
        
        {
          &(NS_GET_IID(nsIDOMNode)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNode*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsINode)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsINode*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsPIDOMEventTarget)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMEventTarget*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMHTMLDocument)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMHTMLDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIScriptObjectPrincipal)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIScriptObjectPrincipal*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSEventTarget)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSEventTarget*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIMutationObserver)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIMutationObserver*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentRange)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentRange*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentStyle)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentStyle*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOM3Node)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOM3Node*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentEvent)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentEvent*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsISupports)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupports*>(
           static_cast<nsIDocument*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIXPathEvaluatorInternal)),
          nsHTMLDocument_LITERAL_CODE_nsIDOMXPathEvaluator,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMNSDocument)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSDocument*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOM3Document)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOM3Document*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOM3DocumentEvent)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOM3DocumentEvent*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSDocumentStyle)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSDocumentStyle*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionParticipant)),
          nsHTMLDocument_STATIC_POINTER,
          { &NS_CYCLE_COLLECTION_NAME(nsHTMLDocument) }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentView)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentView*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDocument)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDocument*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMEventTarget)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMEventTarget*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIHTMLDocument)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIHTMLDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSHTMLDocument)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSHTMLDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMXPathEvaluator)),
          nsHTMLDocument_LITERAL_CODE_nsIDOMXPathEvaluator,
          {0}
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentXBL)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentXBL*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocument)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocument*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIClassInfo)),
          nsHTMLDocument_DOMCI,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOMDocumentTraversal)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMDocumentTraversal*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsIRadioGroupContainer)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIRadioGroupContainer*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionISupports)),
          nsHTMLDocument_CC_ISUPPORTS,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOM3EventTarget)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOM3EventTarget*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
        {
          &(NS_GET_IID(nsISupportsWeakReference)),
          nsHTMLDocument_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupportsWeakReference*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsDocument*>(static_cast<nsHTMLDocument*>(((nsHTMLDocument*) 0x1000)))))
   }
        },
    
      };

      nsISupports* found = nsnull;
      const nsHTMLDocument_QIAction *entry;
      PRUint32 index =
#ifdef IS_BIG_ENDIAN
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#else
        (reinterpret_cast<const PRUint32*>(&aIID)[0] & 0x7f) >> 0;
#endif

      PRUint8 action = kLookupTable[index];
      if (action == 0xFF)
        goto unfound;

      entry = kActionTable + action;
      if (!entry->iid->Equals(aIID))
        goto unfound;

      
      switch (entry->action) {
      
      case nsHTMLDocument_OFFSET_THIS_ADDREF:
        
        found = reinterpret_cast<nsISupports*>(reinterpret_cast<char*>(this) + entry->data.offset);
        goto exit_addref;
    
    
      case nsHTMLDocument_DOMCI:
        
      found = NS_GetDOMClassInfoInstance(eDOMClassInfo_HTMLDocument_id);
      goto exit_nullcheck_addref;
    
    
      case nsHTMLDocument_LITERAL_CODE_nsIDOMXPathEvaluator:
        if (!mXPathEvaluatorTearoff) {nsresult rv;mXPathEvaluatorTearoff =do_CreateInstance(NS_XPATH_EVALUATOR_CONTRACTID,static_cast<nsIDocument *>(this), &rv);NS_ENSURE_SUCCESS(rv, rv);}return mXPathEvaluatorTearoff->QueryInterface(aIID, aResult);
    
      case nsHTMLDocument_STATIC_POINTER:
        *aResult = entry->data.ptr;
                   return NS_OK;
    
      case nsHTMLDocument_CC_ISUPPORTS:
        
        found = NS_CYCLE_COLLECTION_CLASSNAME(nsHTMLDocument)::Upcast(this);
        goto exit_nullcheck_addref;
    
    
      }
    

      NS_NOTREACHED("Unhandled case?");

      
    exit_nullcheck_addref:
      if (!found)
        return NS_ERROR_OUT_OF_MEMORY;
    

    exit_addref:
      NS_ASSERTION(found, "Interface should have been found by now.");
      found->AddRef();
      *aResult = found;
      return NS_OK;

    unfound:
      
      *aResult = nsnull;
      return NS_NOINTERFACE;
    
    }
