#include "nsIDOMWindowInternal.h"
#include "nsIDOMWindow2.h"
#include "nsIDOMJSWindow.h"
#include "nsIDOMEventTarget.h"
#include "nsIDOM3EventTarget.h"
#include "nsIDOMNSEventTarget.h"
#include "nsIDOMViewCSS.h"
#include "nsIDOMAbstractView.h"
#include "nsIDOMStorageWindow.h"
#include "nsIWeakReference.h"
#include "nsIInterfaceRequestor.h"
#include "nsGlobalWindow.h"
#include "nsDOMClassInfo.h"

    enum nsGlobalWindow_QIActionType {
      nsGlobalWindow_OFFSET_THIS_ADDREF, nsGlobalWindow_DOMCI, nsGlobalWindow_STATIC_POINTER, nsGlobalWindow_CC_ISUPPORTS
    };

    struct nsGlobalWindow_QIAction {
      const nsID *iid;
      nsGlobalWindow_QIActionType action;
      union {
        void *ptr;
        
        PRUint32 offset;
    
      } data;
    };

    NS_IMETHODIMP nsGlobalWindow::QueryInterface(REFNSIID aIID, void **aResult)
    {
      
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionParticipant = { 0x9674489b, 0x1f6f, 0x4550, { 0xa7, 0x30, 0xcc, 0xae, 0xdd, 0x10, 0x4c, 0xf9 } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionParticipant).Equals(kGQI_nsCycleCollectionParticipant),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMWindow = { 0x909852b5, 0xb9e6, 0x4d94, { 0x8d, 0xe3, 0x05, 0x16, 0x34, 0x80, 0x0b, 0x73 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMWindow).Equals(kGQI_nsPIDOMWindow),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsPIDOMEventTarget = { 0x44a6597b, 0x9fc3, 0x4a8d, { 0xb7, 0xa4, 0xd9, 0x00, 0x9a, 0xbf, 0x9d, 0x15 } };
        NS_ASSERTION(NS_GET_IID(nsPIDOMEventTarget).Equals(kGQI_nsPIDOMEventTarget),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIScriptGlobalObject = { 0x6afecd40, 0x0b9a, 0x4cfd, { 0x8c, 0x42, 0x0f, 0x64, 0x5c, 0xd9, 0x18, 0x29 } };
        NS_ASSERTION(NS_GET_IID(nsIScriptGlobalObject).Equals(kGQI_nsIScriptGlobalObject),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIScriptObjectPrincipal = { 0x3eedba38, 0x8d22, 0x41e1, { 0x81, 0x7a, 0x0e, 0x43, 0xe1, 0x65, 0xb6, 0x64 } };
        NS_ASSERTION(NS_GET_IID(nsIScriptObjectPrincipal).Equals(kGQI_nsIScriptObjectPrincipal),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsIClassInfo = { 0x986c11d0, 0xf340, 0x11d4, { 0x90, 0x75, 0x00, 0x10, 0xa4, 0xe7, 0x3d, 0x9a } };
        NS_ASSERTION(NS_GET_IID(nsIClassInfo).Equals(kGQI_nsIClassInfo),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        
        #ifdef DEBUG
        static const nsID kGQI_nsCycleCollectionISupports = { 0xc61eac14, 0x5f7a, 0x4481, { 0x96, 0x5e, 0x7e, 0xaa, 0x6e, 0xff, 0xa8, 0x5f } };
        NS_ASSERTION(NS_GET_IID(nsCycleCollectionISupports).Equals(kGQI_nsCycleCollectionISupports),
                     "GQI pseudo-IID doesn't match reality.");
        #endif
        

      static const PRUint8 kLookupTable[] = {
#ifdef IS_BIG_ENDIAN
        8,
0xFF,
0xFF,
0xFF,
0xFF,
13,
0,
0xFF,
7,
0xFF,
5,
15,
0xFF,
0xFF,
0xFF,
0xFF,
11,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
9,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
6,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
14,
0xFF,
0xFF,
0xFF,
4,
0xFF,
0xFF,
12,
1,
16,
0xFF,
10,
0xFF,
3,
0xFF,
0xFF,
0xFF,
0xFF,
19,
0xFF
#else
        8,
0xFF,
0xFF,
0xFF,
0xFF,
13,
0,
0xFF,
7,
0xFF,
5,
15,
0xFF,
0xFF,
0xFF,
0xFF,
11,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
2,
0xFF,
9,
17,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
18,
6,
0xFF,
0xFF,
0xFF,
0xFF,
0xFF,
14,
0xFF,
0xFF,
0xFF,
4,
0xFF,
0xFF,
12,
1,
16,
0xFF,
10,
0xFF,
3,
0xFF,
0xFF,
0xFF,
0xFF,
19,
0xFF
#endif
      };

      static const nsGlobalWindow_QIAction kActionTable[] = {
        
        {
          &(NS_GET_IID(nsIDOMAbstractView)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMAbstractView*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMJSWindow)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMJSWindow*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionParticipant)),
          nsGlobalWindow_STATIC_POINTER,
          { &NS_CYCLE_COLLECTION_NAME(nsGlobalWindow) }
        },
    
        {
          &(NS_GET_IID(nsPIDOMWindow)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMWindow*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsPIDOMEventTarget)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsPIDOMEventTarget*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIInterfaceRequestor)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIInterfaceRequestor*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIScriptGlobalObject)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIScriptGlobalObject*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIScriptObjectPrincipal)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIScriptObjectPrincipal*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsISupports)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupports*>(
           static_cast<nsIScriptGlobalObject*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMStorageWindow)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMStorageWindow*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMWindow2)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMWindow2*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIClassInfo)),
          nsGlobalWindow_DOMCI,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOMEventTarget)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMEventTarget*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMNSEventTarget)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMNSEventTarget*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMWindow)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMWindow*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsISupportsWeakReference)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsISupportsWeakReference*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMViewCSS)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMViewCSS*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsCycleCollectionISupports)),
          nsGlobalWindow_CC_ISUPPORTS,
          { 0 }
        },
    
        {
          &(NS_GET_IID(nsIDOM3EventTarget)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOM3EventTarget*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
        {
          &(NS_GET_IID(nsIDOMWindowInternal)),
          nsGlobalWindow_OFFSET_THIS_ADDREF,
          
   { reinterpret_cast<void*>(
       reinterpret_cast<char*>(
         static_cast<nsIDOMWindowInternal*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000)))) -
       reinterpret_cast<char*>(static_cast<nsGlobalWindow*>(((nsGlobalWindow*) 0x1000))))
   }
        },
    
      };

      nsISupports* found = nsnull;
      const nsGlobalWindow_QIAction *entry;
      PRUint32 index =
#ifdef IS_BIG_ENDIAN
        (reinterpret_cast<const PRUint32*>(&aIID)[1] & 0xfc0000) >> 18;
#else
        (reinterpret_cast<const PRUint32*>(&aIID)[1] & 0xfc) >> 2;
#endif

      PRUint8 action = kLookupTable[index];
      if (action == 0xFF)
        goto unfound;

      entry = kActionTable + action;
      if (!entry->iid->Equals(aIID))
        goto unfound;

      
      switch (entry->action) {
      
      case nsGlobalWindow_OFFSET_THIS_ADDREF:
        
        found = reinterpret_cast<nsISupports*>(reinterpret_cast<char*>(this) + entry->data.offset);
        goto exit_addref;
    
    
      case nsGlobalWindow_DOMCI:
        
      found = NS_GetDOMClassInfoInstance(eDOMClassInfo_Window_id);
      goto exit_nullcheck_addref;
    
    
      case nsGlobalWindow_STATIC_POINTER:
        *aResult = entry->data.ptr;
                   return NS_OK;
    
      case nsGlobalWindow_CC_ISUPPORTS:
        
        found = NS_CYCLE_COLLECTION_CLASSNAME(nsGlobalWindow)::Upcast(this);
        goto exit_nullcheck_addref;
    
    
      }
    

      NS_NOTREACHED("Unhandled case?");

      
    exit_nullcheck_addref:
      if (!found)
        return NS_ERROR_OUT_OF_MEMORY;
    

    exit_addref:
      NS_ASSERTION(found, "Interface should have been found by now.");
      found->AddRef();
      *aResult = found;
      return NS_OK;

    unfound:
      
      *aResult = nsnull;
      return NS_NOINTERFACE;
    
    }
